package com.bonus.canteen.core.kitchen.mapper;

import java.util.List;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceLife;

/**
 * 厨房设备生命周期Mapper接口
 * 
 * @author xsheng
 * @date 2025-06-16
 */
public interface KitchenDeviceLifeMapper {
    /**
     * 查询厨房设备生命周期
     * 
     * @param id 厨房设备生命周期主键
     * @return 厨房设备生命周期
     */
    public KitchenDeviceLife selectKitchenDeviceLifeById(Long id);

    /**
     * 查询厨房设备生命周期列表
     * 
     * @param kitchenDeviceLife 厨房设备生命周期
     * @return 厨房设备生命周期集合
     */
    public List<KitchenDeviceLife> selectKitchenDeviceLifeList(KitchenDeviceLife kitchenDeviceLife);

    /**
     * 新增厨房设备生命周期
     * 
     * @param kitchenDeviceLife 厨房设备生命周期
     * @return 结果
     */
    public int insertKitchenDeviceLife(KitchenDeviceLife kitchenDeviceLife);

    /**
     * 修改厨房设备生命周期
     * 
     * @param kitchenDeviceLife 厨房设备生命周期
     * @return 结果
     */
    public int updateKitchenDeviceLife(KitchenDeviceLife kitchenDeviceLife);

    /**
     * 删除厨房设备生命周期
     * 
     * @param id 厨房设备生命周期主键
     * @return 结果
     */
    public int deleteKitchenDeviceLifeById(Long id);

    /**
     * 批量删除厨房设备生命周期
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteKitchenDeviceLifeByIds(Long[] ids);
}
