package com.bonus.canteen.core.kitchen.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.kitchen.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.kitchen.domain.KitchenDeviceLife;
import com.bonus.canteen.core.kitchen.service.IKitchenDeviceLifeService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 厨房设备生命周期Controller
 * 
 * @author xsheng
 * @date 2025-06-16
 */
@Api(tags = "厨房设备生命周期接口")
@RestController
@RequestMapping("/kitchen_device_life")
public class KitchenDeviceLifeController extends BaseController {
    @Autowired
    private IKitchenDeviceLifeService kitchenDeviceLifeService;

    /**
     * 查询厨房设备生命周期列表
     */
    @ApiOperation(value = "查询厨房设备生命周期列表")
    //@RequiresPermissions("kitchen:life:list")
    @GetMapping("/list")
    public TableDataInfo list(KitchenDeviceLife kitchenDeviceLife) {
        startPage();
        List<KitchenDeviceLife> list = kitchenDeviceLifeService.selectKitchenDeviceLifeList(kitchenDeviceLife);
        return getDataTable(list);
    }

    /**
     * 导出厨房设备生命周期列表
     */
    @ApiOperation(value = "导出厨房设备生命周期列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:life:export")
    @SysLog(title = "厨房设备生命周期", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出厨房设备生命周期")
    @PostMapping("/export")
    public void export(HttpServletResponse response, KitchenDeviceLife kitchenDeviceLife) {
        List<KitchenDeviceLife> list = kitchenDeviceLifeService.selectKitchenDeviceLifeList(kitchenDeviceLife);
        ExcelUtil<KitchenDeviceLife> util = new ExcelUtil<KitchenDeviceLife>(KitchenDeviceLife.class);
        util.exportExcel(response, list, "厨房设备生命周期数据");
    }

    /**
     * 获取厨房设备生命周期详细信息
     */
    @ApiOperation(value = "获取厨房设备生命周期详细信息")
    //@RequiresPermissions("kitchen:life:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(kitchenDeviceLifeService.selectKitchenDeviceLifeById(id));
    }

    /**
     * 新增厨房设备生命周期
     */
    @ApiOperation(value = "新增厨房设备生命周期")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:life:add")
    @SysLog(title = "厨房设备生命周期", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增厨房设备生命周期")
    @PostMapping
    public AjaxResult add(@RequestBody KitchenDeviceLife kitchenDeviceLife) {
        try {
            return toAjax(kitchenDeviceLifeService.insertKitchenDeviceLife(kitchenDeviceLife));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改厨房设备生命周期
     */
    @ApiOperation(value = "修改厨房设备生命周期")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:life:edit")
    @SysLog(title = "厨房设备生命周期", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改厨房设备生命周期")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody KitchenDeviceLife kitchenDeviceLife) {
        try {
            return toAjax(kitchenDeviceLifeService.updateKitchenDeviceLife(kitchenDeviceLife));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除厨房设备生命周期
     */
    @ApiOperation(value = "删除厨房设备生命周期")
    //@PreventRepeatSubmit
    //@RequiresPermissions("kitchen:life:remove")
    @SysLog(title = "厨房设备生命周期", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除厨房设备生命周期")
	@PostMapping("/del/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(kitchenDeviceLifeService.deleteKitchenDeviceLifeByIds(ids));
    }
}
